//NIST/ITL StRD
//Dataset Name:  DanWood           (DanWood.dat)
//
//File Format:   ASCII
//               Starting Values   (lines 41 to 42)
//               Certified Values  (lines 41 to 47)
//               Data              (lines 61 to 66)
//
//Procedure:     Nonlinear Least Squares Regression
//
//Description:   These data and model are described in Daniel and Wood
//               (1980), and originally published in E.S.Keeping, 
//               "Introduction to Statistical Inference," Van Nostrand
//               Company, Princeton, NJ, 1962, p. 354.  The response
//               variable is energy radieted from a carbon filament
//               lamp per cm**2 per second, and the predictor variable
//               is the absolute temperature of the filament in 1000
//               degrees Kelvin.
//
//Reference:     Daniel, C. and F. S. Wood (1980).
//               Fitting Equations to Data, Second Edition. 
//               New York, NY:  John Wiley and Sons, pp. 428-431.
//
//
//Data:          1 Response Variable  (y = energy)
//               1 Predictor Variable (x = temperature)
//               6 Observations
//               Lower Level of Difficulty
//               Observed Data
//
//Model:         Miscellaneous Class
//               2 Parameters (b1 and b2)
//
//               y  = b1*x**b2  +  e
funDef='b1*x.^b2'; pDef='b1 b2'; Names='y x';
dfunDef='[b(x.^b2),b1*(x.^b2).*log(x)]';
deff('yhat=DanWood(b,x)','yhat=b(1)*x.^b(2)');
//
//
// 
//          Starting values                  Certified Values
//
//        Start 1     Start 2           Parameter     Standard Deviation
//  b1 =   1           0.7           7.6886226176E-01  1.8281973860E-02
//  b2 =   5           4             3.8604055871E+00  5.1726610913E-02
// 
bInit1=[1 5]';
bInit2=[.7 4]';
b=[7.6886226176E-01; 3.8604055871E+00];
resSS=4.3173084083E-03;
//Residual Sum of Squares:                    4.3173084083E-03
//Residual Standard Deviation:                3.2853114039E-02
//Degrees of Freedom:                                4
//Number of Observations:                            6 
// 
// 
// 
// 
// 
// 
// 
// 
// 
// 
// 
// 
//Data:  y              x
Data=[
      2.138E0        1.309E0
      3.421E0        1.471E0
      3.597E0        1.490E0
      4.340E0        1.565E0
      4.882E0        1.611E0
      5.660E0        1.680E0
];

