//NIST/ITL StRD
//Dataset Name:  Rat42             (Rat42.dat)
//
//File Format:   ASCII
//               Starting Values   (lines 41 to 43)
//               Certified Values  (lines 41 to 48)
//               Data              (lines 61 to 69)
//
//Procedure:     Nonlinear Least Squares Regression
//
//Description:   This model and data are an example of fitting
//               sigmoidal growth curves taken from Ratkowsky (1983).
//               The response variable is pasture yield, and the
//               predictor variable is growing time.
//
//
//Reference:     Ratkowsky, D.A. (1983).  
//               Nonlinear Regression Modeling.
//               New York, NY:  Marcel Dekker, pp. 61 and 88.
//
//
//
//
//
//Data:          1 Response  (y = pasture yield)
//               1 Predictor (x = growing time)
//               9 Observations
//               Higher Level of Difficulty
//               Observed Data
//
//Model:         Exponential Class
//               3 Parameters (b1 to b3)
//
//               y = b1 / (1+exp[b2-b3*x])  +  e
funDef='b1 ./ (1+exp(b2-b3*x))'; pDef='b1 b2 b3'; Names='y x';
dfunDef='[ones(x)./(1+exp(b2-b3*x)),-b1*exp(b2-b3*x)./(exp(b2-b3*x)+1).^2,b1*x.*exp(b2-b3*x)./(exp(b2-b3*x)+1).^2]';
deff('yhat=Rat42(b,x)','yhat=b(1) ./ (1+exp(b(2)-b(3)*x))');
//
//
//
//          Starting Values                  Certified Values
//
//        Start 1     Start 2           Parameter     Standard Deviation
//  b1 =   100         75            7.2462237576E+01  1.7340283401E+00
//  b2 =     1          2.5          2.6180768402E+00  8.8295217536E-02
//  b3 =     0.1        0.07         6.7359200066E-02  3.4465663377E-03
//
bInit1=[100 1 .1]';
bInit2=[75 2.5 0.07]';
b=[7.2462237576E+01;2.6180768402E+00;6.7359200066E-02];
resSS=8.0565229338E+00;
//Residual Sum of Squares:                    8.0565229338E+00
//Residual Standard Deviation:                1.1587725499E+00
//Degrees of Freedom:                                6
//Number of Observations:                            9 
//
//
//
//
//
//
//
//
//
//
//
//Data:   y              x
Data=[
       8.930E0        9.000E0
      10.800E0       14.000E0
      18.590E0       21.000E0
      22.330E0       28.000E0
      39.350E0       42.000E0
      56.110E0       57.000E0
      61.730E0       63.000E0
      64.620E0       70.000E0
      67.080E0       79.000E0
];

