//NIST/ITL StRD
//Dataset Name:  Thurber           (Thurber.dat)
//
//File Format:   ASCII
//               Starting Values   (lines 41 to 47)
//               Certified Values  (lines 41 to 52)
//               Data              (lines 61 to 97)
//
//Procedure:     Nonlinear Least Squares Regression
//
//Description:   These data are the result of a NIST study involving
//               semiconductor electron mobility.  The response 
//               variable is a measure of electron mobility, and the 
//               predictor variable is the natural log of the density.
//
//
//Reference:     Thurber, R., NIST (197?).  
//               Semiconductor electron mobility modeling.
//
//
//
//
//
//
//Data:          1 Response Variable  (y = electron mobility)
//               1 Predictor Variable (x = log[density])
//               37 Observations
//               Higher Level of Difficulty
//               Observed Data
//
//Model:         Rational Class (cubic/cubic)
//               7 Parameters (b1 to b7)
//
//               y = (b1 + b2*x + b3*x**2 + b4*x**3) / 
//                   (1 + b5*x + b6*x**2 + b7*x**3)  +  e
//
funDef='(b1+b2*x+b3*x.^2+b4*x.^3)./(1+b5*x+b6*x.^2+b7*x.^3)'; 
dfunDef='[ones(x)./(b7*x.^3+b6*x.^2+b5*x+1),x./(b7*x.^3+b6*x.^2+b5*x+1),(x.^2)./(b7*x.^3+b6*x.^2+b5*x+1),(x.^3)./(b7*x.^3+b6*x.^2+b5*x+1),-x.*(b4*x.^3+b3*x.^2+b2*x+b1)./(b7*x.^3+b6*x.^2+b5*x+1).^2,-(x.^2).*(b4*x.^3+b3*x.^2+b2*x+b1)./(b7*x.^3+b6*x.^2+b5*x+1).^2,-(x.^3).*(b4*x.^3+b3*x.^2+b2*x+b1)./(b7*x.^3+b6*x.^2+b5*x+1).^2]';
pDef='b1 b2 b3 b4 b5 b6 b7'; Names='y x';
deff('yhat=thurber(b,x)',..
  'yhat=(b(1)+b(2)*x+b(3)*x.^2+b(4)*x.^3)./(1+b(5)*x+b(6)*x.^2+b(7)*x.^3)');

//
//          Starting Values                  Certified Values
//
//        Start 1     Start 2           Parameter     Standard Deviation
//  b1 =   1000        1300          1.2881396800E+03  4.6647963344E+00
//  b2 =   1000        1500          1.4910792535E+03  3.9571156086E+01
//  b3 =    400         500          5.8323836877E+02  2.8698696102E+01
//  b4 =     40          75          7.5416644291E+01  5.5675370270E+00
//  b5 =      0.7         1          9.6629502864E-01  3.1333340687E-02
//  b6 =      0.3         0.4        3.9797285797E-01  1.4984928198E-02
//  b7 =      0.03        0.05       4.9727297349E-02  6.5842344623E-03
bInit1=[1000 1000 400 40 .7 .3 .03]';
bInit2=[1300 1500 500 75 1 .4 .05]';
b=[1.2881396800E+03; 1.4910792535E+03; 5.8323836877E+02; 7.5416644291E+01; 9.6629502864E-01; 3.9797285797E-01 ; 4.9727297349E-02];
resSS=5.6427082397E+03;
//
//Residual Sum of Squares:                    5.6427082397E+03
//Residual Standard Deviation:                1.3714600784E+01
//Degrees of Freedom:                                30
//Number of Observations:                            37
//
//
//
//
//
//
//
//Data:   y             x
Data=[
      80.574E0      -3.067E0
      84.248E0      -2.981E0
      87.264E0      -2.921E0
      87.195E0      -2.912E0
      89.076E0      -2.840E0
      89.608E0      -2.797E0
      89.868E0      -2.702E0
      90.101E0      -2.699E0
      92.405E0      -2.633E0
      95.854E0      -2.481E0
     100.696E0      -2.363E0
     101.060E0      -2.322E0
     401.672E0      -1.501E0
     390.724E0      -1.460E0
     567.534E0      -1.274E0
     635.316E0      -1.212E0
     733.054E0      -1.100E0
     759.087E0      -1.046E0
     894.206E0      -0.915E0
     990.785E0      -0.714E0
    1090.109E0      -0.566E0
    1080.914E0      -0.545E0
    1122.643E0      -0.400E0
    1178.351E0      -0.309E0
    1260.531E0      -0.109E0
    1273.514E0      -0.103E0
    1288.339E0       0.010E0
    1327.543E0       0.119E0
    1353.863E0       0.377E0
    1414.509E0       0.790E0
    1425.208E0       0.963E0
    1421.384E0       1.006E0
    1442.962E0       1.115E0
    1464.350E0       1.572E0
    1468.705E0       1.841E0
    1447.894E0       2.047E0
    1457.628E0       2.200E0
];


